from .client import DiaramaAPIClient
from .auth import Auth
from .players import Players
from .games import Games
from .payments import Payments
from .media import Media
from .platforms import Platforms

class DiaramaAPI:
    def __init__(self, api_key):
        self.client = DiaramaAPIClient(api_key)
        self.auth = Auth(self.client)
        self.players = Players(self.client)
        self.games = Games(self.client)
        self.payments = Payments(self.client)
        self.media = Media(self.client)
        self.platforms = Platforms(self.client)



class Media:
    def __init__(self, client):
        self.client = client

    def create_image(self, url, alt_text=None):
        data = {"url": url}
        if alt_text:
            data["alt_text"] = alt_text
        return self.client._post("/media/images", data)

    def create_avatar(self, image_id):
        return self.client._post("/media/avatars", {"image_id": image_id})

    def create_banner(self, image_id):
        return self.client._post("/media/banners", {"image_id": image_id})

    def upload(self, file_obj):
        """Загрузить файл как медиа"""
        files = {'file': file_obj}
        return self.client._post("/media/upload", files=files)



class Games:
    def __init__(self, client):
        self.client = client

    def list(self):
        return self.client._get("/games/")

    def get(self, game_id):
        return self.client._get(f"/games/{game_id}")

    def create(self, name, version, author, description, platform_id, media_id):
        data = {
            "name": name,
            "version": version,
            "author": author,
            "description": description,
            "platform_id": platform_id,
            "media_id": media_id
        }
        return self.client._post("/games/", data)

    def update(self, game_id, **kwargs):
        allowed = ["name", "version", "author", "description", "platforms", "media_id"]
        data = {k: v for k, v in kwargs.items() if k in allowed}
        return self.client._put(f"/games/{game_id}", data)

    def delete(self, game_id):
        return self.client._delete(f"/games/{game_id}")



class Players:
    def __init__(self, client):
        self.client = client

    def list(self):
        return self.client._get("/players/")

    def get(self, player_id: int):
        return self.client._get(f"/players/{player_id}")

    def create(self, username, password, email, role_id=None, avatar_id=None):
        data = {"username": username, "password": password, "email": email}
        if role_id: data["role_id"] = role_id
        if avatar_id: data["avatar_id"] = avatar_id
        return self.client._post("/players/", data)

    def update(self, player_id, **kwargs):
        allowed = ["email", "banned", "role_id", "avatar_id"]
        data = {k: v for k, v in kwargs.items() if k in allowed}
        return self.client._put(f"/players/{player_id}", data)

    def delete(self, player_id):
        return self.client._delete(f"/players/{player_id}")



# api/platforms.py
class Platforms:
    def __init__(self, client):
        self.client = client

    def list(self):
        """Получить список всех платформ"""
        return self.client._get("/platforms/")

    def get(self, platform_id):
        """Получить платформу по ID"""
        return self.client._get(f"/platforms/{platform_id}")

    def create(self, name):
        """Создать новую платформу"""
        data = {"name": name}
        return self.client._post("/platforms/", data)

    def update(self, platform_id, name):
        """Обновить платформу"""
        data = {"name": name}
        return self.client._put(f"/platforms/{platform_id}", data)

    def delete(self, platform_id):
        """Удалить платформу"""
        return self.client._delete(f"/platforms/{platform_id}")



class Auth:
    def __init__(self, client):
        self.client = client

    def create_key(self, name: str):
        return self.client._post("/auth/create-key", {"name": name})

    def list(self):
        return self.client._get("/auth/keys")

    def deactivate(self, key_id: int):
        return self.client._delete(f"/auth/keys/{key_id}")



class Payments:
    def __init__(self, client):
        self.client = client

    def list(self, player_id=None):
        params = {"player_id": player_id} if player_id else None
        return self.client._get("/payments/", params=params)

    def create(self, player_id, game_id, price, platform_id=None, paystatus_id=None):
        data = {"player_id": player_id, "game_id": game_id, "price": price}
        if platform_id: data["platform_id"] = platform_id
        if paystatus_id: data["paystatus_id"] = paystatus_id
        return self.client._post("/payments/", data)

    def update_status(self, payment_id, paystatus_id):
        return self.client._put(f"/payments/{payment_id}", {"paystatus_id": paystatus_id})



import json
import requests

class DiaramaAPIClient:
    def __init__(self, api_key: str, base_url: str = "https://api.diaramastudio.ru"):
        self.api_key = api_key
        self.base_url = base_url
        self.headers = {
            "X-API-Key": api_key,
            "Content-Type": "application/json; charset=utf-8"
        }

    def _get(self, endpoint, params=None):
        r = requests.get(f"{self.base_url}{endpoint}", headers=self.headers, params=params)
        r.raise_for_status()
        return r.json()

    def _post(self, endpoint, data=None):
        json_data = json.dumps(data, ensure_ascii=False).encode('utf-8')
        r = requests.post(f"{self.base_url}{endpoint}", headers=self.headers, data=json_data)
        r.raise_for_status()
        return r.json()

    def _put(self, endpoint, data=None):
        json_data = json.dumps(data, ensure_ascii=False).encode('utf-8')
        r = requests.put(f"{self.base_url}{endpoint}", headers=self.headers, data=json_data)
        r.raise_for_status()
        return r.json()

    def _delete(self, endpoint):
        r = requests.delete(f"{self.base_url}{endpoint}", headers=self.headers)
        r.raise_for_status()
        return r.json()
